Term Opinions

| Site Search |

MICHIGAN COURTS |

MICHIGAN SUPREME COURT

| New! Subscribe to RSS feed Instructions>>
# Opinions of the Michigan Supreme Court Please note orders are not posted here. To search for a recent order (not an opinion), other case information, or to search opinions by party, case type, or lower court, please click here>> The slip opinions collected here are those issued during MSC Term (October 1 through July 31). These opinions are posted on this website within hours after the bench opinions are issued. To view pdf files, you must use Adobe Acrobat. Download Adobe Acrobat free. Further information may be obtained by calling the Supreme Court Clerk's Office at 517-373-0120.
2011-12 Term Opinions |  |  |
2010-11 Term Opinions | 2009-10 Term Opinions | 2008-09 Term Opinions | 2007-08 Term Opinions
## 2011-12 Term Opinions
Opinion Date | Docket Number(s) | Case Name (click on case name to link to opinion)
06/08/12 | 142031 | People v Watkins
06/08/12 | 142751 | People v Pullen
06/05/12 | 142127 | Johnson v Pastoriza
05/31/12 | 142695, 142712 & 142850 | People v Kolanek (Alexander) People v King (Larry)
05/30/12 | 142956 | DeFrain v State Farm Mutual Automobile Insurance Company
05/30/12 | 142442-3 | People v Laidler (Marteez)
05/25/12 | 143046 | People v Cole (David)
05/24/12 | 142698 | People v Buie (James)
05/17/12 | 142537 | People v Rao (Malini)
05/17/12 | 141810 | Dept of Environmental Quality v Worth Township
05/15/12 | 141161 | People v Williams (Glenn)
05/15/12 | 142615 | Joseph v ACIA
05/14/12 | 142913 | People v Reese
05/04/12 | 142759 & 143673 | In Re C.I. Morris, minor In Re J.L. Gordon, minor
04/20/12 | 141837 | People v Moreno
03/26/12 | 141381 | People v Evans (Lamar)
01/27/12 | 142076 | In Re Hon. James M. Justin
12/21/11 | 142545, 142547 | Frazier v Allstate
11/18/11 | 143157 | In Re Request for Advisory Opinion Regarding Constitutionality of 2011 PA 38
10/26/11 | 142762 | People v Armstrong
## 2010-11 Term Opinions
Opinion Date | Docket Number(s) | Case Name(click on case name to link to opinion)
08/01/11 | 140922 | Driver v Cardiovascular Clinic
07/29/11 | 140937 | Duffy v DNR
07/29/11 | 140945 | Krohn v Home-Owners Ins
07/29/11 | 141752 | People v Richardson
07/29/11 | 139978 | Ligons v Crittenton Hospital
07/29/11 | 139505 | Hamed v Wayne County
07/28/11 | 139856 | People v Fackelman
07/26/11 | 140510 | People v Bonilla-Machado
07/26/11 | 141312 | People v Huston
07/26/11 | 141695 | People v Kowalski
7/11/11 | 140603 | People v Dowdy
7/11/11 | 139666 | Miller-Davis Company v Ahrens Construction, Inc.
07/01/11 | 141009 | People v Slaughter
06/30/11 | 137451 | Michigan Education Assn v Secretary of State
06/30/11 | 140683 | Clarke v Richco Construction
06/30/11 | 141570 | People v Lee
06/14/11 | 140524 | People v Peltola
06/06/11 | 141168 | Loweke v Ann Arbor Ceiling
06/03/11 | 139394 | Beach v Township of Lima
05/23/11 | 140814 and 140817 to 14082 | Midland Cogeneration v Naftaly Iron Mountain v Naftaly
05/17/11 | 139189 | Priority Health v Commissioner of the Office of Financial and Insurance Services
05/17/11 | 142550 | Attorney General v 54-A District Court Judge
05/09/11 | 139541 | Great Wolf Lodge of Traverse City, LLC v Public Service Commission
04/28/11 | 140153 | People v Breidenbach
03/10/11 | 140423 | Klooster v City of Charlevoix
01/14/11 | 139969 | People v Lown
12/29/10 | 137451 | Michigan Education Association v Secretary of State
12/29/10 | 140684 | King v State of Michigan, et al
12/29/10 | 140371 | People v Smith
12/29/10 | 139617 | 2000 Baum Family Trust, et al v Babel, et al
12/20/10 | 140842 | In re Beck, Minors
10/29/10 | 140263 | In re Certified Question (Waeschle v Oakland Co Med Examiner)
## 2009-10 Term Opinions
Opinion Date | Docket Number(s) | Case Name(click on case name to link to opinion)
09/07/10 | 137755 | People v Tennyson
09/07/10 | 138988 | People v Jackson (Leonard)
08/26/10 | 140021 | People v Szalma
08/23/10 | 138908 | Shay v Aldrich
07/31/10 | 138401 | LSEA v Lansing Board of Education
07/31/10 | 136905 | U of M Regents v Titan Ins
07/31/10 | 136738 | McCormick v Carrier
07/31/10 | 138180-138181 | O'Neal v St John Hospital & Medical Center
07/31/10 | 137500 | Bezeau v Palace Sports & Entertainment, Inc.
07/31/10 | 139146 | People v Mardlin
07/31/10 | 138959 | People v Houthoofd
07/30/10 | 138456 to 138458 | Smith v Anonymous Joint Enterprise, et al
07/30/10 | 138920, 138921 | Brightwell & Champion v Fifth Third Bank of MI
07/27/10 | 138460 | Tkachik v Mandeville
07/27/10 | 138258 | People v Flick (Steven Edward)
07/27/10 | 138261 | People v Lazarus (Douglas Brent)
07/23/10 | 138668 | People v Hill
07/23/10 | 139396 | People v Dupree (Roberto Marchello)
07/22/10 | 138187 | Edry v Adelman
07/22/10 | 137251 | People v Gursky (Jason Michael)
07/15/10 | 136680 | Kyser v Kasson Twp.
07/15/10 | 137446, 137447 | Hendee v Putnam Twp.
07/14/10 | 137424, 137453 | Adair v State of Michigan
07/13/10 | 137993 | Holman v Rasak
07/08/10 | 137400, 137407 | Ins Institute of Mich, et al v Comm'r, Fin & Ins Svcs
07/01/10 | 139872 | Foster v Wolkowitz
06/28/10 | 137111 | Pellegrino v AMPCO Parking
06/18/10 | 137443 | Shepherd Montessori v Ann Arbor Charter Twp
06/18/10 | 137347 | Woodman v Kera LLC
06/08/10 | 138031 | People v Feezel
05/26/10 | 139795 | In re Mason, Minors (DHS v Mason)
05/25/10 | 137480 | DeCosta v Gossage
05/11/10 | 136956 | People v Wilcox (Larry Eugene)
05/11/10 | 138824 | Pierron v Pierron
05/10/10 | 139068 | Brewer v A.D. Transport Express
04/30/10 | 136648 | People v Richmond
04/07/10 | 138669 | Robinson v City of Lansing
03/30/10 | 137562 | People v Wilder (Darrell)
03/30/10 | 137092 | Dawe v Bar-Levav
03/30/10 | 138168, 138179, 138182 | Briggs Tax Service v Detroit Public Schools et al
03/30/10 | 138123 | People v Plunkett (Ronald James)
03/10/10 | 137552 | Dept of Agriculture v Appletree Marketing
## 2008-09 Term Opinions
Opinion Date | Docket Number(s) | Case Name(click on case name to link to opinion)
08/13/09 | 137284 | People v Lowe (Jamie Lynn)
07/31/09 | 137301 | People v Idziak (Patrick)
07/31/09 | 137633 | In re Honorable Steven R. Servaas
07/31/09 | 136298 | Henry v Dow Chemical
07/31/09 | 136542, 136543 | Petersen v MAGNA Corp.
07/31/09 | 136336 | Potter v McLeary
07/31/09 | 136310 | Hunter v Hunter
07/30/09 | 136423 | Jackson v Estate of Ronald Green
07/29/09 | 136617 | Bush v Shabahang
07/28/09 | 132876 | People v McGraw (Matthew)
07/21/09 | 134437 | McNeil v Charlevoix County
07/21/09 | 133466 & 133468 | USF&G v MI Catastrophic Claims Ass'n (Also see Order of 7/21/09)
07/17/09 | 136436 | Kahn v Bakshi
07/14/09 | 137653 | Dept of Human Services v Cheryl Lynn Lee
07/10/09 | 135888 | People v Jackson (Harvey)
07/09/09 | 135271 | People v Williams (Carletus)
07/01/09 | 134967 | People v Borgne (Michael)
07/01/09 | 135435 | People v Shafier (Harold)
06/10/09 | 133725 | People v Bryant
06/10/09 | 137486 | People v Holder (Gregory)
04/02/09 | 134461 | In Re Raymond Estate
04/02/09 | 136849 | In Re Ayden Rood, Minor
04/01/09 | 136382 | Zahn v Kroger, et al
03/31/09 | 135546 | Romain v Frankenmuth Ins.
03/18/09 | 136751 | People v Swafford (Kobeay)
12/30/08 | 135028 | Moore v Secura Ins
12/30/08 | 133433 | Odom v Wayne County
12/30/08 | 134665 | Tomacek v Bavas, et al
12/30/08 | 135989 | People v Miller (Michael)
12/29/08 | 133466 & 133468 | USF&G v MI Catastrophic Claims Ass'n (Also see Order of 3/27/09)
12/17/08 | 136880 | In Re Honorable William C. Hultgren
12/22/08 | 129693 | People v Maxson (Mark Allen)
## 2007-08 Term Opinions
Opinion Date | Docket Number(s) | Case Name(click on case name to link to opinion)
9/08/08 | 137136 | Citizens Protecting Michigan's Constitution v Reform Michigan Government Now! To view Order, click here>>
7-31-08 | 134682 | People v Smith (Gary)
7-30-08 | 135375 | Brackett v Focus Hope
7-30-08 | 133394 | Daimlerchrysler v State Tax Commission
7-24-08 | 133986 | Stone v Williamson
7-23-08 | 131942 | People v Gardner
7-23-08 | 134751 | White v Taylor Distributing
7-23-08 | 134493, 134500 | SBC v MPSC
7-23-08 | 132916 | Pontiac Fire Fighters v City of Pontiac
7-23-08 | 131463 | Detroit Fire Fighters v City of Detroit
7-16-08 | 131103 | Manuel v Gill
7-16-08 | 133682 | State News v MSU
7-16-08 | 133819 | Michigan Federation of Teachers v U of M
7-9-08 | 134087 | Dimmett & Owens Financial v DeLoitte & Touche
7-2-08 | 132688 | Boodt v Borgess Medical Center
7-2-08 | 134393 | Miller v Allstate
7-2-08 | 131905 | Sidun v Wayne Treasurer
7-2-08 | 133098 | Estes v Titus
7-2-08 | 132823 | Smith v Khouri
6-25-08 | 133771 | Allison v AEW
6-25-08 | 135023 | Michigan Association of Home Builders v MDLEG
6-25-08 | 134473 | People v Blackston
6-25-08 | 131479 | Walters v Nadell
6-25-08 | 132792 | Cooper v Auto Club Insurance Association
6-18-08 | 136101 | People v Muttscheler
6-18-08 | 133474 | People v Sargent
6-18-08 | 134097 | Herman v County of Berrien
6-13-08 | 133929 | In Re Beverley Nettles-Nickerson
6-12-08 | 132648 | Stokes v Daimlerchrysler
6-11-08 | 132203 | Kuznar v Raksha Corporation
6-11-08 | 132983 | MI Dept of Transportation v Tomkins
6-11-08 | 134913 | People v Ream
6-04-08 | 135405 | Lemmen v Lemmen
6-04-08 | 131994 | People v Cannon
6-19-08 (as amended) | 132042 | People v Katherine Sue Dendel

Get the latest version of Internet Explorer. Some of the files on this site are PDF files. To view PDF files, you need Acrobat Reader. Download your free copy here. Technical questions about this site should be sent to webinfo@courts.mi.gov. Questions about the content on this site should be sent to msc-info@courts.mi.gov. |